US  9,423,690  B2

239

The resins  (P-1) to  (P-4),  (P-6) to  (P-14),  (P-16),  (P-22),  (P-24) to  (P-26),  (P-28) to  (P-38),  (P-42) to  (P-44),  (P-47),  (P-51),  (P-53),  (P-57),  (P-61)  to  (P-64),  (P-66),  (P-71)  to  (P-73), (P-77), (P-78) to (P-91) were synthesized in the same  manner as in resin (P-5). The synthesized polymer structure  is  described previously as  specific  examples.

In  addition,  the weight  average  molecular weight  (Mw)  and the polydispersity  (Mw/Mn)  of each resin,  which was  synthesized  as  described  above  and  will  be  used  in  the  Examples being described later,  are shown in the following  table.

## TABLE  1

## TABLE 2

240

## TABLE 2-continued

As  for  the  Comparative  Examples,  the  following  resin  C-1  was  synthesized  according  to  the  above-described  method and used in the Examples as  described below.  The  polymer  structure,  the  weight  average  molecular  weight  (Mw)  and  the  polydispersity  (Mw/Mn)  of resin  C-1  are  shown below. Further, the composition ratio of each repeat› ing unit of  the polymer structure is shown in the molar ratio.

Illustration

Illustration

Mw: 10000

Mw/Mn:1.60

[Hydrophobic  Resin]

The  hydrophobic  resin  was  appropriately  selected  from  the  above-examplified hydrophobic  resins  HR-1  to  HR-34  and then used.

Hereinafter,  the  composition  ratio  (molar  ratio)  of  the  hydrophobic  resin,  the  weight  average  molecular  weight  (Mw) and the polydispersity (Mw/Mn) will be described.

## TABLE 3

[Photo-Acid Generator]

The photo-acid generator was appropriately selected from  the above-examplified acid generators  zl to  z141, and then  used.

<!-- missing-key-value-item -->